@@ -69,7 +69,7 @@ greddit_eat_data (void *buffer, size_t size, size_t nmemb, void *targetp)
   target->size += size*nmemb;
 
   /* make sure it's null-terminated */
-  target->content[target->size+1] = 0;
+  target->content[target->size] = 0;
 
   if (target->callback)
     target->callback (target->size, target->total);
@@ -172,6 +172,17 @@ greddit_get_posts_with_callback (GRedditLoadingCallback callback)
       p->author = g_strdup (json_node_get_string (json_object_get_member (post, "author")));
       p->subreddit = g_strdup (json_node_get_string (json_object_get_member (post, "subreddit")));
       p->score = json_node_get_int (json_object_get_member (post, "score"));
+      p->comment_count = json_node_get_int (json_object_get_member (post, "num_comments"));
+
+      p->suffix = index (p->id, '_');
+      if (p->suffix)
+	{
+	  p->suffix++;
+	}
+      else
+	{
+	  p->suffix = p->id;
+	}
 
       result = g_slist_insert_sorted (result, p, greddit_post_compare);
     }
