@@ -113,6 +113,22 @@ read_comments_cb (GRedditPost *post, gboolean prepare)
     }
 }
 
+static gchar*
+share_cb (GRedditPost *post, gboolean prepare)
+{
+  if (prepare)
+    {
+      return g_strdup_printf ("Share");
+    }
+  else
+    {
+      sharing_choice (window,
+		      post->url,
+		      post->title);
+      return NULL;
+    }
+}
+
 typedef gchar* (*OptionCallback) (GRedditPost *, gboolean);
 
 static void
@@ -122,6 +138,7 @@ options_selector (GtkButton *dummy,
   OptionCallback callbacks[] = {
     visit_site_cb,
     read_comments_cb,
+    share_cb,
     NULL
   };
   OptionCallback *oc_cursor;
